Crate relative_path [−] [src]
A platform-neutral relative path.
This provide types which are analogous to Path, and PathBuf found in stdlib, with the
following characteristics:
- The path separator is set to a fixed character (
/), regardless of platform. - Relative paths cannot represent an absolute path in the filesystem, without first specifying
what they are relative to through
to_path.
Serde Support
This library includes serde support that can be enabled with the serde feature.
Structs
| Components |
Iterator over all the components in a relative path. |
| Display | |
| RelativePath |
A borrowed, immutable relative path. |
| RelativePathBuf |
An owned, mutable relative path. |
Enums
| Component |